@@ -182,3 +182,31 @@ async fn release_dhcp_lease() -> Result<(), ClientError> {
 
     Ok(())
 }
+
+#[tokio::test]
+async fn list_routes() -> Result<(), ClientError> {
+    let base = Url::parse("https://10.0.10.1")?;
+    let mut client = Client::new(base, "admin".to_string(), "ifd783far".to_string(), true)
+        .expect("error in creating client");
+
+    let response = mikrotik::ip::route::list(&mut client).await?;
+
+    println!("{:?}", response);
+
+    Ok(())
+}
+
+#[tokio::test]
+async fn get_route() -> Result<(), ClientError> {
+    let base = Url::parse("https://10.0.10.1")?;
+    let mut client = Client::new(base, "admin".to_string(), "ifd783far".to_string(), true)
+        .expect("error in creating client");
+
+    let response = mikrotik::ip::route::list(&mut client).await?;
+
+    let response = mikrotik::ip::route::get(&mut client, &response[0].id).await?;
+
+    println!("{:?}", response);
+
+    Ok(())
+}
